autowisp.processing_steps.calibrate module — AutoWISP documentation

# autowisp.processing_steps.calibrate module

## Class Inheritance Diagram

Calibrate image(s).

class autowisp.processing_steps.calibrate.ParseChannelDependentAction(option_strings, dest, nargs=None, const=None, default=None, type=None, choices=None, required=False, help=None, metavar=None)

  Bases: `_StoreAction`

  Parse command line arguments with channel dependent values.

  __call__(parser, namespace, values, option_string=None)

    Parse a channel dependent option.

  static _format_result(result, option_string)

    Format the parsed result per the option being parsed.

class autowisp.processing_steps.calibrate.ParseChannelsAction(option_strings, dest, nargs=None, const=None, default=None, type=None, choices=None, required=False, help=None, metavar=None)

  Bases: `Action`

  Parse chanel command line arguments as described in the help.

  __call__(parser, namespace, values, option_string=None)

    Parse all channels into a dictionary as required by Calibrator.

autowisp.processing_steps.calibrate.calibrate(image_collection, start_status, configuration, mark_start, mark_end)

  Calibrate the images from the specified collection.

autowisp.processing_steps.calibrate.cleanup_interrupted(interrupted, configuration)

  Cleanup file system after partially calibrated images.

autowisp.processing_steps.calibrate.main()

  Run the step from the command line.

autowisp.processing_steps.calibrate.parse_area_str(area_str)

  Parse a string formatted as <xmin>,<xmax>,<ymin>,<ymax> to dict.

autowisp.processing_steps.calibrate.parse_command_line(*args)

  Return the parsed command line arguments.

autowisp.processing_steps.calibrate.parse_overscan(overscan_str)

  Parse the –overscans argument to dict as required by Calibrator.